@@ -200,7 +200,7 @@ class BaseScheduler(object):
                     if os.getpid() == process_id:
                         if self.scheduler.get_job(job_id=apscheduler_id):
                             self.scheduler.remove_job(job_id=apscheduler_id)
-                        self.scheduler_add_job(apscheduler_id=apscheduler_id, crawler_info=update_value)
+                        self.scheduler_add_job(**update_value)
                         self.redis_db.delete_key(lock_name=update_key)
                     else:
                         self.process_check_count(process_id=process_id, check_key=update_key)
